@@ -9,7 +9,7 @@ use List::Util qw(uniq any first);
 use Moose::Util::TypeConstraints qw(enum subtype where);
 use namespace::autoclean;
 
-our $VERSION = '2.5';
+our $VERSION = '2.6';
 
 with
     'Dist::Zilla::Role::PluginBundle::Easy',
@@ -254,10 +254,12 @@ sub configure {
         [
             'Encoding' => [
                 encoding => 'bytes',
-                match    => 'ico',
-                match    => 'docx',
-                match    => 'zip',
-                match    => 'ztb', # Mintlab specific, just a zip file
+                match    => '\.ico$',
+                match    => '\.docx?$',
+                match    => '\.zip$',
+                match    => '\.ztb$', # Mintlab specific, just a zip file
+                match    => '\.pdf$',
+                match    => '\.odt$',
             ]
         ],
 
@@ -356,7 +358,7 @@ Dist::Zilla::PluginBundle::Author::WATERKIP - An plugin bundle for all distribut
 
 =head1 VERSION
 
-version 2.5
+version 2.6
 
 =head1 SYNOPSIS
 
@@ -416,10 +418,12 @@ following F<dist.ini>:
 
     [Encoding]
     encoding = bytes
-    match = ico
-    match = docx
-    match = zip
-    match = ztb ; Mintlab specific
+    match = \.ico$
+    match = \.docx?$
+    match = \.zip$
+    match = \.ztb$ ; Mintlab specific
+    match = \.pdf$
+    match = \.odt$
 
     [CPANFile]
 
